@@ -112,7 +112,7 @@ class WebBrowser:
   def waitForPageLoaded(self):
     time.sleep(1)
     def page_has_loaded():
-      self.logger.info("Wait for page loaded...")
+      self.logger.info("Đang chờ tải trang web...")
       page_state = self.driver.execute_script('return document.readyState;')
       return page_state == 'complete'
     self.waitFor(page_has_loaded)
@@ -120,7 +120,7 @@ class WebBrowser:
   def waitForGhiNhan(self):
     def page_has_loaded():
       status = 'loading'
-      search = self.searchElement("Captcha empty", 'XPATH', '//input[@formcontrolname="maCapcha"]', 1, 0, 1)
+      search = self.searchElement("Captcha empty", 'XPATH', '//input[@formcontrolname="textCaptcha"]', 1, 0, 1)
       if search:
         search_value = search.get_attribute('value')
         if not search_value or len(search_value) == 0:
@@ -340,7 +340,7 @@ class WebBrowser:
 
     # Go to Captcha
     self.logger.info("Nhap Captcha")
-    self.moveToElement("Captcha Textbox", 'XPATH', '//input[@formcontrolname="maCapcha"]', 10, 2,2)
+    self.moveToElement("Captcha Textbox", 'XPATH', '//input[@formcontrolname="textCaptcha"]', 10, 2,2)
 
   def waitCaptcha(self, file_cd, file_mt, file_ms, ho_ten, ma_so_str, cmnd_str, tinh_tp_str, huyen_str, xa_str, dia_chi, so_dt_str, chon_bhxh_hm=False):
     status = ""
@@ -350,7 +350,7 @@ class WebBrowser:
     last_Captcha = "new"
     search_value = "new"
     for i in range(60):
-      search = self.searchElement("[%i] Nhap Captcha" % (i), 'XPATH', '//input[@formcontrolname="maCapcha"]', 4, 0, 2)
+      search = self.searchElement("[%i] Nhap Captcha" % (i), 'XPATH', '//input[@formcontrolname="textCaptcha"]', 4, 0, 2)
       if search:
         search_value = search.get_attribute('value')
         search_value = search_value.upper()
@@ -366,7 +366,7 @@ class WebBrowser:
       # Da nhap
       if not '@' in search_value and len(search_value) == 4:
         if last_Captcha != search_value:
-          search = self.searchElement("[%i] Cap nhat Captcha" % (i), 'XPATH', '//input[@formcontrolname="maCapcha"]', 2, 0, 2)
+          search = self.searchElement("[%i] Cap nhat Captcha" % (i), 'XPATH', '//input[@formcontrolname="textCaptcha"]', 2, 0, 2)
           if search:
             search_value = search.get_attribute('value')
             for c in search_value:
@@ -429,7 +429,7 @@ class WebBrowser:
             self.logger.error("Da co loi")
             status = "error"
             # xóa Captcha đã nhập
-            search = self.searchElement('Captcha box-xoa', 'XPATH', '//input[@formcontrolname="maCapcha"]', 4, 0, 2)
+            search = self.searchElement('Captcha box-xoa', 'XPATH', '//input[@formcontrolname="textCaptcha"]', 4, 0, 2)
             search.clear()
             # làm mới Captcha
             #self.searchClick('Lam moi Captcha', 'XPATH', '//*[@id="form-cnt"]/div[11]/div[3]/div/div/div/div[2]/a/img', 4, 0, 2)
@@ -437,7 +437,7 @@ class WebBrowser:
           else:
             status = "error"
             # xóa Captcha đã nhập
-            search = self.searchElement('Captcha box-xoa', 'XPATH', '//input[@formcontrolname="maCapcha"]', 4, 0, 2)
+            search = self.searchElement('Captcha box-xoa', 'XPATH', '//input[@formcontrolname="textCaptcha"]', 4, 0, 2)
             search.clear()
             # làm mới Captcha
             # self.searchClick('Lam moi Captcha', 'XPATH', '//*[@id="form-cnt"]/div[11]/div[3]/div/div/div/div[2]/a/img', 4, 0, 2)
